==> tzafon-1.3.2.tar.gz: tzafon-1.3.2/CHANGELOG.md <==
# Changelog

## 1.3.2 (2025-10-08)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/atulgavandetzafon/computer-python/compare/v1.3.1...v1.3.2)

### Chores

* update SDK settings ([05f237e](https://github.com/atulgavandetzafon/computer-python/commit/05f237ee8b8b72f28301dda597201e051f1b7ef4))
* update SDK settings ([89b4df6](https://github.com/atulgavandetzafon/computer-python/commit/89b4df64ee207a368dfa80e9ae47a9255da4d545))

## 1.3.1 (2025-10-08)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/atulgavandetzafon/computer-python/compare/v1.3.0...v1.3.1)

## 1.3.0 (2025-10-08)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** manual updates ([92a3ec3](https://github.com/atulgavandetzafon/computer-python/commit/92a3ec3c358004e432973fedd6844add8bcb1c7d))

## 1.2.0 (2025-10-08)

Full Changelog: [v1.1.4...v1.2.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.4...v1.2.0)

### Features

* **api:** manual updates ([8ce5b6b](https://github.com/atulgavandetzafon/computer-python/commit/8ce5b6bc92fffc1baf956972489ceefbf987be3b))
* **api:** manual updates ([8fa5045](https://github.com/atulgavandetzafon/computer-python/commit/8fa5045b6bfbf00a3d44833100d36b58d27a83e3))
* **api:** manual updates ([3dc796f](https://github.com/atulgavandetzafon/computer-python/commit/3dc796fb27186307f81f6e3ad93e6715a707604d))
* **api:** manual updates ([ff7ae66](https://github.com/atulgavandetzafon/computer-python/commit/ff7ae66be8c4d9c69b52f803b23a0456aebe3c1e))
* **api:** manual updates ([3492063](https://github.com/atulgavandetzafon/computer-python/commit/3492063eeb600e5c42585ebc8805b50cc0ffe9c0))
* **api:** manual updates ([a68cfdb](https://github.com/atulgavandetzafon/computer-python/commit/a68cfdb2689829e82063eb672e1736e9f66bd81e))
* **api:** manual updates ([0e7ee2c](https://github.com/atulgavandetzafon/computer-python/commit/0e7ee2ca2568511b495a154a6b802dd5c4b42908))

## 1.1.4 (2025-10-08)

Full Changelog: [v1.1.3...v1.1.4](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.3...v1.1.4)

## 1.1.3 (2025-10-08)

Full Changelog: [v1.1.2...v1.1.3](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.2...v1.1.3)

## 1.1.2 (2025-10-08)

Full Changelog: [v1.1.1...v1.1.2](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.1...v1.1.2)

## 1.1.1 (2025-10-08)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.0...v1.1.1)

## 1.1.0 (2025-10-07)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** manual updates ([aaf8e53](https://github.com/atulgavandetzafon/computer-python/commit/aaf8e534415ea6bc8420f2ed8e3b854011a7bf71))
* **api:** manual updates ([833115e](https://github.com/atulgavandetzafon/computer-python/commit/833115e5e6814f6347de3e0521faceb4bf9e15e8))


### Chores

* update SDK settings ([0b62c4b](https://github.com/atulgavandetzafon/computer-python/commit/0b62c4b04323dabf192fe31e11f45ea94f366411))

## 1.0.1 (2025-10-07)

Full Changelog: [v0.0.1...v1.0.1](https://github.com/atulgavandetzafon/computer-python/compare/v0.0.1...v1.0.1)

### Features

* **api:** added python ([7bc6a73](https://github.com/atulgavandetzafon/computer-python/commit/7bc6a73f549bb57bb176de454d395fd692159a0e))
* **api:** manual updates ([57e4841](https://github.com/atulgavandetzafon/computer-python/commit/57e4841180a11f953e1d8db5e3c1ea7eebbb1d3e))
* **api:** manual updates ([a23814e](https://github.com/atulgavandetzafon/computer-python/commit/a23814e85afaa64e2a429b2bcb6507b0accb46bc))
* **api:** Updated to bearer auth ([c95903e](https://github.com/atulgavandetzafon/computer-python/commit/c95903e3795de2823b6266f914647dd55dc4eeba))
* **api:** v2 api ([db7fdb5](https://github.com/atulgavandetzafon/computer-python/commit/db7fdb5cbcb3ed5f38c2fcebe824573172c223d1))
* async ([38d796c](https://github.com/atulgavandetzafon/computer-python/commit/38d796c6538fad278abf122887a57a379c5a532b))
* lets test functionality ([3d5f515](https://github.com/atulgavandetzafon/computer-python/commit/3d5f515098e71964a431849a37c88a7a017424d2))
* wrapper test1 ([e329ec1](https://github.com/atulgavandetzafon/computer-python/commit/e329ec12ae711d64cad28e04a74bd7c1283669ce))


### Bug Fixes

* removed old async ([1b5c5cd](https://github.com/atulgavandetzafon/computer-python/commit/1b5c5cdf4a7c80089e8ca67e13540bdae898ac98))


### Chores

* update SDK settings ([a5da45a](https://github.com/atulgavandetzafon/computer-python/commit/a5da45a676c091d3d02fde9352d98d458e4dfe7f))
* update SDK settings ([3e68f6d](https://github.com/atulgavandetzafon/computer-python/commit/3e68f6db27fae3f75f411d76e15a6df07d22fa2b))

==> tzafon-2.3.1.tar.gz: tzafon-2.3.1/CHANGELOG.md <==
# Changelog

## 2.3.1 (2025-11-03)

Full Changelog: [v2.3.0...v2.3.1](https://github.com/tzafon/computer-python/compare/v2.3.0...v2.3.1)

## 2.3.0 (2025-11-03)

Full Changelog: [v2.2.0...v2.3.0](https://github.com/tzafon/computer-python/compare/v2.2.0...v2.3.0)

### Features

* **api:** manual updates ([4247614](https://github.com/tzafon/computer-python/commit/4247614c9c5d391d84c80b7ad36dbc89002f1ec8))

## 2.2.0 (2025-11-03)

Full Changelog: [v2.1.0...v2.2.0](https://github.com/tzafon/computer-python/compare/v2.1.0...v2.2.0)

### Features

* **api:** api update ([4950128](https://github.com/tzafon/computer-python/commit/4950128991e4e714562709df3d84eb0f1270677b))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([b2a3169](https://github.com/tzafon/computer-python/commit/b2a3169289c6e5117cd42973594618e232e7eb1d))
* remove custom code ([fa3ccd4](https://github.com/tzafon/computer-python/commit/fa3ccd4b257623a59e61db225e65e0ee415b3517))

## 2.1.0 (2025-10-30)

Full Changelog: [v2.0.1...v2.1.0](https://github.com/tzafon/computer-python/compare/v2.0.1...v2.1.0)

### Features

* **api:** api update ([2a38a7f](https://github.com/tzafon/computer-python/commit/2a38a7f2bb027dd6cd627df075d0c8c4399e615d))


### Bug Fixes

* **client:** close streams without requiring full consumption ([24a5a11](https://github.com/tzafon/computer-python/commit/24a5a114bcb3d3d4ed0c0b5df158e09c99d78a79))

## 2.0.1 (2025-10-21)

Full Changelog: [v2.0.0...v2.0.1](https://github.com/tzafon/computer-python/compare/v2.0.0...v2.0.1)

## 2.0.0 (2025-10-20)

Full Changelog: [v1.4.0...v2.0.0](https://github.com/tzafon/computer-python/compare/v1.4.0...v2.0.0)

### Features

* **api:** manual updates ([29bf74f](https://github.com/tzafon/computer-python/commit/29bf74fecae0fe2aaa70a9f6f5f7ca64ba5ddbff))

## 1.4.0 (2025-10-20)

Full Changelog: [v1.3.2...v1.4.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.3.2...v1.4.0)

### Features

* **api:** manual updates ([6405afc](https://github.com/atulgavandetzafon/computer-python/commit/6405afc6031ccdc2e65dbd935d54c340c148a675))
* renamed api key ([6800a00](https://github.com/atulgavandetzafon/computer-python/commit/6800a0019d321a9bc121745b1b3f9697b52ac565))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([f5e4b7e](https://github.com/atulgavandetzafon/computer-python/commit/f5e4b7ed3a9a62190715a3e426e0c9cd430ad7d7))
* **internal:** detect missing future annotations with ruff ([3c69485](https://github.com/atulgavandetzafon/computer-python/commit/3c69485eb903332d717f99730319c50f9a6a5776))

## 1.3.2 (2025-10-08)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/atulgavandetzafon/computer-python/compare/v1.3.1...v1.3.2)

### Chores

* update SDK settings ([05f237e](https://github.com/atulgavandetzafon/computer-python/commit/05f237ee8b8b72f28301dda597201e051f1b7ef4))
* update SDK settings ([89b4df6](https://github.com/atulgavandetzafon/computer-python/commit/89b4df64ee207a368dfa80e9ae47a9255da4d545))

## 1.3.1 (2025-10-08)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/atulgavandetzafon/computer-python/compare/v1.3.0...v1.3.1)

## 1.3.0 (2025-10-08)

Full Changelog: [v1.2.0...v1.3.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.2.0...v1.3.0)

### Features

* **api:** manual updates ([92a3ec3](https://github.com/atulgavandetzafon/computer-python/commit/92a3ec3c358004e432973fedd6844add8bcb1c7d))

## 1.2.0 (2025-10-08)

Full Changelog: [v1.1.4...v1.2.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.4...v1.2.0)

### Features

* **api:** manual updates ([8ce5b6b](https://github.com/atulgavandetzafon/computer-python/commit/8ce5b6bc92fffc1baf956972489ceefbf987be3b))
* **api:** manual updates ([8fa5045](https://github.com/atulgavandetzafon/computer-python/commit/8fa5045b6bfbf00a3d44833100d36b58d27a83e3))
* **api:** manual updates ([3dc796f](https://github.com/atulgavandetzafon/computer-python/commit/3dc796fb27186307f81f6e3ad93e6715a707604d))
* **api:** manual updates ([ff7ae66](https://github.com/atulgavandetzafon/computer-python/commit/ff7ae66be8c4d9c69b52f803b23a0456aebe3c1e))
* **api:** manual updates ([3492063](https://github.com/atulgavandetzafon/computer-python/commit/3492063eeb600e5c42585ebc8805b50cc0ffe9c0))
* **api:** manual updates ([a68cfdb](https://github.com/atulgavandetzafon/computer-python/commit/a68cfdb2689829e82063eb672e1736e9f66bd81e))
* **api:** manual updates ([0e7ee2c](https://github.com/atulgavandetzafon/computer-python/commit/0e7ee2ca2568511b495a154a6b802dd5c4b42908))

## 1.1.4 (2025-10-08)

Full Changelog: [v1.1.3...v1.1.4](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.3...v1.1.4)

## 1.1.3 (2025-10-08)

Full Changelog: [v1.1.2...v1.1.3](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.2...v1.1.3)

## 1.1.2 (2025-10-08)

Full Changelog: [v1.1.1...v1.1.2](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.1...v1.1.2)

## 1.1.1 (2025-10-08)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/atulgavandetzafon/computer-python/compare/v1.1.0...v1.1.1)

## 1.1.0 (2025-10-07)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/atulgavandetzafon/computer-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** manual updates ([aaf8e53](https://github.com/atulgavandetzafon/computer-python/commit/aaf8e534415ea6bc8420f2ed8e3b854011a7bf71))
* **api:** manual updates ([833115e](https://github.com/atulgavandetzafon/computer-python/commit/833115e5e6814f6347de3e0521faceb4bf9e15e8))


### Chores

* update SDK settings ([0b62c4b](https://github.com/atulgavandetzafon/computer-python/commit/0b62c4b04323dabf192fe31e11f45ea94f366411))

## 1.0.1 (2025-10-07)

Full Changelog: [v0.0.1...v1.0.1](https://github.com/atulgavandetzafon/computer-python/compare/v0.0.1...v1.0.1)

### Features

* **api:** added python ([7bc6a73](https://github.com/atulgavandetzafon/computer-python/commit/7bc6a73f549bb57bb176de454d395fd692159a0e))
* **api:** manual updates ([57e4841](https://github.com/atulgavandetzafon/computer-python/commit/57e4841180a11f953e1d8db5e3c1ea7eebbb1d3e))
* **api:** manual updates ([a23814e](https://github.com/atulgavandetzafon/computer-python/commit/a23814e85afaa64e2a429b2bcb6507b0accb46bc))
* **api:** Updated to bearer auth ([c95903e](https://github.com/atulgavandetzafon/computer-python/commit/c95903e3795de2823b6266f914647dd55dc4eeba))
* **api:** v2 api ([db7fdb5](https://github.com/atulgavandetzafon/computer-python/commit/db7fdb5cbcb3ed5f38c2fcebe824573172c223d1))
* async ([38d796c](https://github.com/atulgavandetzafon/computer-python/commit/38d796c6538fad278abf122887a57a379c5a532b))
* lets test functionality ([3d5f515](https://github.com/atulgavandetzafon/computer-python/commit/3d5f515098e71964a431849a37c88a7a017424d2))
* wrapper test1 ([e329ec1](https://github.com/atulgavandetzafon/computer-python/commit/e329ec12ae711d64cad28e04a74bd7c1283669ce))


### Bug Fixes

* removed old async ([1b5c5cd](https://github.com/atulgavandetzafon/computer-python/commit/1b5c5cdf4a7c80089e8ca67e13540bdae898ac98))


### Chores

* update SDK settings ([a5da45a](https://github.com/atulgavandetzafon/computer-python/commit/a5da45a676c091d3d02fde9352d98d458e4dfe7f))
* update SDK settings ([3e68f6d](https://github.com/atulgavandetzafon/computer-python/commit/3e68f6db27fae3f75f411d76e15a6df07d22fa2b))
